@@ -1,6 +1,10 @@
 import argparse
 import pathlib
 
+from .logging import get_logger
+
+logger = get_logger("cppygen command")
+
 import toml
 
 from cppygen.cppygen_parser import Parser
@@ -23,19 +27,31 @@ def run():
     cwd = pathlib.Path(args.cwd)
 
     sources = []
+    if configs["sources"] is None:
+        logger.error("Please Specify the sources field in config file")
+        exit(1)
     for i in configs["sources"]:
-        sources.extend([i for i in cwd.glob(i)])
+        sources.extend([j for j in cwd.glob(i)])
 
     headers = []
+    if configs["headers"] is None:
+        logger.error("Please Specify the headers field in config file")
+        exit(1)
     for i in configs["headers"]:
-        headers.extend([i for i in cwd.glob(i)])
+        headers.extend([j for j in cwd.glob(i)])
 
+    if configs["output_dir"] is None:
+        logger.error("Please Specify the output_dir field in config file")
+        exit(1)
     output_dir = cwd.joinpath(configs["output_dir"])
 
-    cppygen = Parser(namespace=configs["search_namespace"])
+    cppygen = Parser(
+        namespace=configs["search_namespace"], library_file=configs["libclang_path"]
+    )
 
-    flags = configs["flags"]
-    for i in configs["include_directories"]:
+    flags = configs["flags"] or []
+
+    for i in configs["include_directories"] or []:
         flags.append(f"-I{str(cwd.joinpath(i).absolute())}")
         print(f"-I{str(cwd.joinpath(i).absolute())}")
 
@@ -45,7 +61,7 @@ def run():
     for i in headers:
         cppygen.parse_from_file(i, lang="hpp", flags=configs["flags"])
 
-    for i in configs["include_headers"]:
+    for i in configs["include_headers"] or []:
         cppygen.add_hpp_includes(i)
 
     with open(str(output_dir) + "/cppygen_generated.hpp", "w") as f:
